@@ -71,8 +71,10 @@ class Template(common.Common):
 
             self.data = parse
             if self.data.get("title"):
-                self.data["title"] = self.replace(
-                    ["，", "\\"], ["_", ""], self.data["title"]
+                self.data["title"] = self.sub(
+                    "[a-zA-Z0-9’!\"#$%&'()*+,-./:;<=>?@，。?★、…【】《》？“”‘’！[\\]^_`{|}~\s]+",
+                    "",
+                    self.data["title"],
                 )
             if "show" in parse:
                 self.prepare_quality(parse)
@@ -80,6 +82,8 @@ class Template(common.Common):
                 self.execute_init()
             elif self.params.get("player") and not self.params.get("query"):
                 self.execute_init()
+            elif self.params.get("info") and not self.params.get("query"):
+                self.execute_init()
             elif self.params.get("json"):
                 if self.get("jsonFilter"):
                     filter = self.jsonFilter.split("|")
